var namespaceIMP_1_1core =
[
    [ "AllSamePairPredicate", "classIMP_1_1core_1_1AllSamePairPredicate.html", "classIMP_1_1core_1_1AllSamePairPredicate" ],
    [ "AllSameQuadPredicate", "classIMP_1_1core_1_1AllSameQuadPredicate.html", "classIMP_1_1core_1_1AllSameQuadPredicate" ],
    [ "AllSameSingletonPredicate", "classIMP_1_1core_1_1AllSameSingletonPredicate.html", "classIMP_1_1core_1_1AllSameSingletonPredicate" ],
    [ "AllSameTripletPredicate", "classIMP_1_1core_1_1AllSameTripletPredicate.html", "classIMP_1_1core_1_1AllSameTripletPredicate" ],
    [ "AngleRestraint", "classIMP_1_1core_1_1AngleRestraint.html", "classIMP_1_1core_1_1AngleRestraint" ],
    [ "AngleTripletScore", "classIMP_1_1core_1_1AngleTripletScore.html", "classIMP_1_1core_1_1AngleTripletScore" ],
    [ "AttributeSingletonPredicate", "classIMP_1_1core_1_1AttributeSingletonPredicate.html", "classIMP_1_1core_1_1AttributeSingletonPredicate" ],
    [ "BallMover", "classIMP_1_1core_1_1BallMover.html", "classIMP_1_1core_1_1BallMover" ],
    [ "BoxSweepClosePairsFinder", "classIMP_1_1core_1_1BoxSweepClosePairsFinder.html", "classIMP_1_1core_1_1BoxSweepClosePairsFinder" ],
    [ "Centroid", "classIMP_1_1core_1_1Centroid.html", "classIMP_1_1core_1_1Centroid" ],
    [ "CentroidOfRefined", "classIMP_1_1core_1_1CentroidOfRefined.html", "classIMP_1_1core_1_1CentroidOfRefined" ],
    [ "ChecksScoreState", "classIMP_1_1core_1_1ChecksScoreState.html", "classIMP_1_1core_1_1ChecksScoreState" ],
    [ "ChildrenRefiner", "classIMP_1_1core_1_1ChildrenRefiner.html", "classIMP_1_1core_1_1ChildrenRefiner" ],
    [ "ClosedCubicSpline", "classIMP_1_1core_1_1ClosedCubicSpline.html", "classIMP_1_1core_1_1ClosedCubicSpline" ],
    [ "ClosePairsFinder", "classIMP_1_1core_1_1ClosePairsFinder.html", "classIMP_1_1core_1_1ClosePairsFinder" ],
    [ "ClosePairsPairScore", "classIMP_1_1core_1_1ClosePairsPairScore.html", "classIMP_1_1core_1_1ClosePairsPairScore" ],
    [ "CoinFlipPairPredicate", "classIMP_1_1core_1_1CoinFlipPairPredicate.html", "classIMP_1_1core_1_1CoinFlipPairPredicate" ],
    [ "CoinFlipQuadPredicate", "classIMP_1_1core_1_1CoinFlipQuadPredicate.html", "classIMP_1_1core_1_1CoinFlipQuadPredicate" ],
    [ "CoinFlipSingletonPredicate", "classIMP_1_1core_1_1CoinFlipSingletonPredicate.html", "classIMP_1_1core_1_1CoinFlipSingletonPredicate" ],
    [ "CoinFlipTripletPredicate", "classIMP_1_1core_1_1CoinFlipTripletPredicate.html", "classIMP_1_1core_1_1CoinFlipTripletPredicate" ],
    [ "ConjugateGradients", "classIMP_1_1core_1_1ConjugateGradients.html", "classIMP_1_1core_1_1ConjugateGradients" ],
    [ "ConnectivityRestraint", "classIMP_1_1core_1_1ConnectivityRestraint.html", "classIMP_1_1core_1_1ConnectivityRestraint" ],
    [ "ConstantPairPredicate", "classIMP_1_1core_1_1ConstantPairPredicate.html", "classIMP_1_1core_1_1ConstantPairPredicate" ],
    [ "ConstantQuadPredicate", "classIMP_1_1core_1_1ConstantQuadPredicate.html", "classIMP_1_1core_1_1ConstantQuadPredicate" ],
    [ "ConstantRestraint", "classIMP_1_1core_1_1ConstantRestraint.html", "classIMP_1_1core_1_1ConstantRestraint" ],
    [ "ConstantSingletonPredicate", "classIMP_1_1core_1_1ConstantSingletonPredicate.html", "classIMP_1_1core_1_1ConstantSingletonPredicate" ],
    [ "ConstantTripletPredicate", "classIMP_1_1core_1_1ConstantTripletPredicate.html", "classIMP_1_1core_1_1ConstantTripletPredicate" ],
    [ "Cosine", "classIMP_1_1core_1_1Cosine.html", "classIMP_1_1core_1_1Cosine" ],
    [ "Cover", "classIMP_1_1core_1_1Cover.html", "classIMP_1_1core_1_1Cover" ],
    [ "CoverRefined", "classIMP_1_1core_1_1CoverRefined.html", "classIMP_1_1core_1_1CoverRefined" ],
    [ "DataObject", "classIMP_1_1core_1_1DataObject.html", "classIMP_1_1core_1_1DataObject" ],
    [ "DerivativesFromRefined", "classIMP_1_1core_1_1DerivativesFromRefined.html", "classIMP_1_1core_1_1DerivativesFromRefined" ],
    [ "DerivativesToRefined", "classIMP_1_1core_1_1DerivativesToRefined.html", "classIMP_1_1core_1_1DerivativesToRefined" ],
    [ "DiameterRestraint", "classIMP_1_1core_1_1DiameterRestraint.html", "classIMP_1_1core_1_1DiameterRestraint" ],
    [ "DihedralRestraint", "classIMP_1_1core_1_1DihedralRestraint.html", "classIMP_1_1core_1_1DihedralRestraint" ],
    [ "DistancePairScore", "classIMP_1_1core_1_1DistancePairScore.html", "classIMP_1_1core_1_1DistancePairScore" ],
    [ "DistanceRestraint", "classIMP_1_1core_1_1DistanceRestraint.html", "classIMP_1_1core_1_1DistanceRestraint" ],
    [ "EdgePairGeometry", "classIMP_1_1core_1_1EdgePairGeometry.html", "classIMP_1_1core_1_1EdgePairGeometry" ],
    [ "EdgePairsGeometry", "classIMP_1_1core_1_1EdgePairsGeometry.html", "classIMP_1_1core_1_1EdgePairsGeometry" ],
    [ "ExcludedVolumeRestraint", "classIMP_1_1core_1_1ExcludedVolumeRestraint.html", "classIMP_1_1core_1_1ExcludedVolumeRestraint" ],
    [ "FixedRefiner", "classIMP_1_1core_1_1FixedRefiner.html", "classIMP_1_1core_1_1FixedRefiner" ],
    [ "Gaussian", "classIMP_1_1core_1_1Gaussian.html", "classIMP_1_1core_1_1Gaussian" ],
    [ "GenericAttributeSingletonScore", "classIMP_1_1core_1_1GenericAttributeSingletonScore.html", "classIMP_1_1core_1_1GenericAttributeSingletonScore" ],
    [ "GenericBoundingBox3DSingletonScore", "classIMP_1_1core_1_1GenericBoundingBox3DSingletonScore.html", "classIMP_1_1core_1_1GenericBoundingBox3DSingletonScore" ],
    [ "GenericDistanceToSingletonScore", "classIMP_1_1core_1_1GenericDistanceToSingletonScore.html", "classIMP_1_1core_1_1GenericDistanceToSingletonScore" ],
    [ "GridClosePairsFinder", "classIMP_1_1core_1_1GridClosePairsFinder.html", "classIMP_1_1core_1_1GridClosePairsFinder" ],
    [ "Harmonic", "classIMP_1_1core_1_1Harmonic.html", "classIMP_1_1core_1_1Harmonic" ],
    [ "HarmonicDistancePairScore", "classIMP_1_1core_1_1HarmonicDistancePairScore.html", "classIMP_1_1core_1_1HarmonicDistancePairScore" ],
    [ "HarmonicLowerBound", "classIMP_1_1core_1_1HarmonicLowerBound.html", "classIMP_1_1core_1_1HarmonicLowerBound" ],
    [ "HarmonicSphereDistancePairScore", "classIMP_1_1core_1_1HarmonicSphereDistancePairScore.html", "classIMP_1_1core_1_1HarmonicSphereDistancePairScore" ],
    [ "HarmonicUpperBound", "classIMP_1_1core_1_1HarmonicUpperBound.html", "classIMP_1_1core_1_1HarmonicUpperBound" ],
    [ "HarmonicUpperBoundSphereDiameterPairScore", "classIMP_1_1core_1_1HarmonicUpperBoundSphereDiameterPairScore.html", "classIMP_1_1core_1_1HarmonicUpperBoundSphereDiameterPairScore" ],
    [ "HarmonicUpperBoundSphereDistancePairScore", "classIMP_1_1core_1_1HarmonicUpperBoundSphereDistancePairScore.html", "classIMP_1_1core_1_1HarmonicUpperBoundSphereDistancePairScore" ],
    [ "HarmonicWell", "classIMP_1_1core_1_1HarmonicWell.html", "classIMP_1_1core_1_1HarmonicWell" ],
    [ "Hierarchy", "classIMP_1_1core_1_1Hierarchy.html", "classIMP_1_1core_1_1Hierarchy" ],
    [ "HierarchyCounter", "structIMP_1_1core_1_1HierarchyCounter.html", "structIMP_1_1core_1_1HierarchyCounter" ],
    [ "HierarchyTraits", "classIMP_1_1core_1_1HierarchyTraits.html", "classIMP_1_1core_1_1HierarchyTraits" ],
    [ "HierarchyVisitor", "classIMP_1_1core_1_1HierarchyVisitor.html", "classIMP_1_1core_1_1HierarchyVisitor" ],
    [ "InBoundingBox3DSingletonPredicate", "classIMP_1_1core_1_1InBoundingBox3DSingletonPredicate.html", "classIMP_1_1core_1_1InBoundingBox3DSingletonPredicate" ],
    [ "IncrementalScoringFunction", "classIMP_1_1core_1_1IncrementalScoringFunction.html", "classIMP_1_1core_1_1IncrementalScoringFunction" ],
    [ "IsCollisionPairPredicate", "classIMP_1_1core_1_1IsCollisionPairPredicate.html", "classIMP_1_1core_1_1IsCollisionPairPredicate" ],
    [ "KClosePairsPairScore", "classIMP_1_1core_1_1KClosePairsPairScore.html", "classIMP_1_1core_1_1KClosePairsPairScore" ],
    [ "LeavesRefiner", "classIMP_1_1core_1_1LeavesRefiner.html", "classIMP_1_1core_1_1LeavesRefiner" ],
    [ "Linear", "classIMP_1_1core_1_1Linear.html", "classIMP_1_1core_1_1Linear" ],
    [ "MCCGSampler", "classIMP_1_1core_1_1MCCGSampler.html", "classIMP_1_1core_1_1MCCGSampler" ],
    [ "MinimumRestraint", "classIMP_1_1core_1_1MinimumRestraint.html", "classIMP_1_1core_1_1MinimumRestraint" ],
    [ "ModifierVisitor", "classIMP_1_1core_1_1ModifierVisitor.html", "classIMP_1_1core_1_1ModifierVisitor" ],
    [ "MonteCarlo", "classIMP_1_1core_1_1MonteCarlo.html", "classIMP_1_1core_1_1MonteCarlo" ],
    [ "MonteCarloMover", "classIMP_1_1core_1_1MonteCarloMover.html", "classIMP_1_1core_1_1MonteCarloMover" ],
    [ "MonteCarloMoverResult", "structIMP_1_1core_1_1MonteCarloMoverResult.html", "structIMP_1_1core_1_1MonteCarloMoverResult" ],
    [ "MonteCarloWithBasinHopping", "classIMP_1_1core_1_1MonteCarloWithBasinHopping.html", "classIMP_1_1core_1_1MonteCarloWithBasinHopping" ],
    [ "MonteCarloWithLocalOptimization", "classIMP_1_1core_1_1MonteCarloWithLocalOptimization.html", "classIMP_1_1core_1_1MonteCarloWithLocalOptimization" ],
    [ "MoveStatisticsScoreState", "classIMP_1_1core_1_1MoveStatisticsScoreState.html", "classIMP_1_1core_1_1MoveStatisticsScoreState" ],
    [ "MSConnectivityRestraint", "classIMP_1_1core_1_1MSConnectivityRestraint.html", "classIMP_1_1core_1_1MSConnectivityRestraint" ],
    [ "NearestNeighborsClosePairsFinder", "classIMP_1_1core_1_1NearestNeighborsClosePairsFinder.html", "classIMP_1_1core_1_1NearestNeighborsClosePairsFinder" ],
    [ "NeighborsTable", "classIMP_1_1core_1_1NeighborsTable.html", "classIMP_1_1core_1_1NeighborsTable" ],
    [ "NonRigidMember", "classIMP_1_1core_1_1NonRigidMember.html", "classIMP_1_1core_1_1NonRigidMember" ],
    [ "NormalizedSphereDistancePairScore", "classIMP_1_1core_1_1NormalizedSphereDistancePairScore.html", "classIMP_1_1core_1_1NormalizedSphereDistancePairScore" ],
    [ "NormalMover", "classIMP_1_1core_1_1NormalMover.html", "classIMP_1_1core_1_1NormalMover" ],
    [ "OpenCubicSpline", "classIMP_1_1core_1_1OpenCubicSpline.html", "classIMP_1_1core_1_1OpenCubicSpline" ],
    [ "OrderedTypePairPredicate", "classIMP_1_1core_1_1OrderedTypePairPredicate.html", "classIMP_1_1core_1_1OrderedTypePairPredicate" ],
    [ "OrderedTypeQuadPredicate", "classIMP_1_1core_1_1OrderedTypeQuadPredicate.html", "classIMP_1_1core_1_1OrderedTypeQuadPredicate" ],
    [ "OrderedTypeSingletonPredicate", "classIMP_1_1core_1_1OrderedTypeSingletonPredicate.html", "classIMP_1_1core_1_1OrderedTypeSingletonPredicate" ],
    [ "OrderedTypeTripletPredicate", "classIMP_1_1core_1_1OrderedTypeTripletPredicate.html", "classIMP_1_1core_1_1OrderedTypeTripletPredicate" ],
    [ "PairConstraint", "classIMP_1_1core_1_1PairConstraint.html", "classIMP_1_1core_1_1PairConstraint" ],
    [ "PairRestraint", "classIMP_1_1core_1_1PairRestraint.html", "classIMP_1_1core_1_1PairRestraint" ],
    [ "PredicateSingletonScore", "classIMP_1_1core_1_1PredicateSingletonScore.html", "classIMP_1_1core_1_1PredicateSingletonScore" ],
    [ "QuadConstraint", "classIMP_1_1core_1_1QuadConstraint.html", "classIMP_1_1core_1_1QuadConstraint" ],
    [ "QuadraticClosePairsFinder", "classIMP_1_1core_1_1QuadraticClosePairsFinder.html", "classIMP_1_1core_1_1QuadraticClosePairsFinder" ],
    [ "QuadRestraint", "classIMP_1_1core_1_1QuadRestraint.html", "classIMP_1_1core_1_1QuadRestraint" ],
    [ "Reference", "classIMP_1_1core_1_1Reference.html", "classIMP_1_1core_1_1Reference" ],
    [ "RefinedPairsPairScore", "classIMP_1_1core_1_1RefinedPairsPairScore.html", "classIMP_1_1core_1_1RefinedPairsPairScore" ],
    [ "RestraintsScoringFunction", "classIMP_1_1core_1_1RestraintsScoringFunction.html", "classIMP_1_1core_1_1RestraintsScoringFunction" ],
    [ "RigidBody", "classIMP_1_1core_1_1RigidBody.html", "classIMP_1_1core_1_1RigidBody" ],
    [ "RigidBodyDerivativeGeometry", "classIMP_1_1core_1_1RigidBodyDerivativeGeometry.html", "classIMP_1_1core_1_1RigidBodyDerivativeGeometry" ],
    [ "RigidBodyDerivativesGeometry", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry.html", "classIMP_1_1core_1_1RigidBodyDerivativesGeometry" ],
    [ "RigidBodyDistancePairScore", "classIMP_1_1core_1_1RigidBodyDistancePairScore.html", "classIMP_1_1core_1_1RigidBodyDistancePairScore" ],
    [ "RigidBodyFrameGeometry", "classIMP_1_1core_1_1RigidBodyFrameGeometry.html", "classIMP_1_1core_1_1RigidBodyFrameGeometry" ],
    [ "RigidBodyFramesGeometry", "classIMP_1_1core_1_1RigidBodyFramesGeometry.html", "classIMP_1_1core_1_1RigidBodyFramesGeometry" ],
    [ "RigidBodyHierarchyGeometry", "classIMP_1_1core_1_1RigidBodyHierarchyGeometry.html", "classIMP_1_1core_1_1RigidBodyHierarchyGeometry" ],
    [ "RigidBodyMember", "classIMP_1_1core_1_1RigidBodyMember.html", "classIMP_1_1core_1_1RigidBodyMember" ],
    [ "RigidBodyMover", "classIMP_1_1core_1_1RigidBodyMover.html", "classIMP_1_1core_1_1RigidBodyMover" ],
    [ "RigidBodyTorque", "classIMP_1_1core_1_1RigidBodyTorque.html", "classIMP_1_1core_1_1RigidBodyTorque" ],
    [ "RigidBodyTunneler", "classIMP_1_1core_1_1RigidBodyTunneler.html", "classIMP_1_1core_1_1RigidBodyTunneler" ],
    [ "RigidBodyUmbrella", "classIMP_1_1core_1_1RigidBodyUmbrella.html", "classIMP_1_1core_1_1RigidBodyUmbrella" ],
    [ "RigidClosePairsFinder", "classIMP_1_1core_1_1RigidClosePairsFinder.html", "classIMP_1_1core_1_1RigidClosePairsFinder" ],
    [ "RigidMember", "classIMP_1_1core_1_1RigidMember.html", "classIMP_1_1core_1_1RigidMember" ],
    [ "SerialMover", "classIMP_1_1core_1_1SerialMover.html", "classIMP_1_1core_1_1SerialMover" ],
    [ "SingletonConstraint", "classIMP_1_1core_1_1SingletonConstraint.html", "classIMP_1_1core_1_1SingletonConstraint" ],
    [ "SingletonRestraint", "classIMP_1_1core_1_1SingletonRestraint.html", "classIMP_1_1core_1_1SingletonRestraint" ],
    [ "SoftSpherePairScore", "classIMP_1_1core_1_1SoftSpherePairScore.html", "classIMP_1_1core_1_1SoftSpherePairScore" ],
    [ "SphereDistancePairScore", "classIMP_1_1core_1_1SphereDistancePairScore.html", "classIMP_1_1core_1_1SphereDistancePairScore" ],
    [ "SphereDistanceToSingletonScore", "classIMP_1_1core_1_1SphereDistanceToSingletonScore.html", "classIMP_1_1core_1_1SphereDistanceToSingletonScore" ],
    [ "StatisticalPairScore", "classIMP_1_1core_1_1StatisticalPairScore.html", "classIMP_1_1core_1_1StatisticalPairScore" ],
    [ "SteepestDescent", "classIMP_1_1core_1_1SteepestDescent.html", "classIMP_1_1core_1_1SteepestDescent" ],
    [ "TableRefiner", "classIMP_1_1core_1_1TableRefiner.html", "classIMP_1_1core_1_1TableRefiner" ],
    [ "Transform", "classIMP_1_1core_1_1Transform.html", "classIMP_1_1core_1_1Transform" ],
    [ "TransformationAndReflectionSymmetry", "classIMP_1_1core_1_1TransformationAndReflectionSymmetry.html", "classIMP_1_1core_1_1TransformationAndReflectionSymmetry" ],
    [ "TransformationSymmetry", "classIMP_1_1core_1_1TransformationSymmetry.html", "classIMP_1_1core_1_1TransformationSymmetry" ],
    [ "TransformedDistancePairScore", "classIMP_1_1core_1_1TransformedDistancePairScore.html", "classIMP_1_1core_1_1TransformedDistancePairScore" ],
    [ "TripletConstraint", "classIMP_1_1core_1_1TripletConstraint.html", "classIMP_1_1core_1_1TripletConstraint" ],
    [ "TripletRestraint", "classIMP_1_1core_1_1TripletRestraint.html", "classIMP_1_1core_1_1TripletRestraint" ],
    [ "TruncatedHarmonic", "classIMP_1_1core_1_1TruncatedHarmonic.html", "classIMP_1_1core_1_1TruncatedHarmonic" ],
    [ "Typed", "classIMP_1_1core_1_1Typed.html", "classIMP_1_1core_1_1Typed" ],
    [ "TypedPairScore", "classIMP_1_1core_1_1TypedPairScore.html", "classIMP_1_1core_1_1TypedPairScore" ],
    [ "UnorderedTypePairPredicate", "classIMP_1_1core_1_1UnorderedTypePairPredicate.html", "classIMP_1_1core_1_1UnorderedTypePairPredicate" ],
    [ "UnorderedTypeQuadPredicate", "classIMP_1_1core_1_1UnorderedTypeQuadPredicate.html", "classIMP_1_1core_1_1UnorderedTypeQuadPredicate" ],
    [ "UnorderedTypeSingletonPredicate", "classIMP_1_1core_1_1UnorderedTypeSingletonPredicate.html", "classIMP_1_1core_1_1UnorderedTypeSingletonPredicate" ],
    [ "UnorderedTypeTripletPredicate", "classIMP_1_1core_1_1UnorderedTypeTripletPredicate.html", "classIMP_1_1core_1_1UnorderedTypeTripletPredicate" ],
    [ "VolumeRestraint", "classIMP_1_1core_1_1VolumeRestraint.html", "classIMP_1_1core_1_1VolumeRestraint" ],
    [ "WeightedDerivativesToRefined", "classIMP_1_1core_1_1WeightedDerivativesToRefined.html", "classIMP_1_1core_1_1WeightedDerivativesToRefined" ],
    [ "WeightedSphereDistancePairScore", "classIMP_1_1core_1_1WeightedSphereDistancePairScore.html", "classIMP_1_1core_1_1WeightedSphereDistancePairScore" ],
    [ "WriteRestraintScoresOptimizerState", "classIMP_1_1core_1_1WriteRestraintScoresOptimizerState.html", "classIMP_1_1core_1_1WriteRestraintScoresOptimizerState" ],
    [ "XYZ", "classIMP_1_1core_1_1XYZ.html", "classIMP_1_1core_1_1XYZ" ],
    [ "XYZDerivativeGeometry", "classIMP_1_1core_1_1XYZDerivativeGeometry.html", "classIMP_1_1core_1_1XYZDerivativeGeometry" ],
    [ "XYZDerivativesGeometry", "classIMP_1_1core_1_1XYZDerivativesGeometry.html", "classIMP_1_1core_1_1XYZDerivativesGeometry" ],
    [ "XYZR", "classIMP_1_1core_1_1XYZR.html", "classIMP_1_1core_1_1XYZR" ],
    [ "XYZRGeometry", "classIMP_1_1core_1_1XYZRGeometry.html", "classIMP_1_1core_1_1XYZRGeometry" ],
    [ "XYZRsGeometry", "classIMP_1_1core_1_1XYZRsGeometry.html", "classIMP_1_1core_1_1XYZRsGeometry" ]
];